import { css, cx } from "@linaria/core";
import { Form } from "ant-design-vue";
import { defineComponent, reactive } from "vue";
import { bool, string } from "vue-types";

export default defineComponent({
  props: {
    label: string(),
    border: bool().def(true),
    disabled: bool(),
    ...Form.Item.props,
  },
  setup(props, { slots }) {
    const state = reactive({
      focused: false,
    });

    return () => {
      const { disabled, border, ...restProps } = props;
      return (
        <Form.Item
          class={cx(
            formItemStyles,
            border && "border",
            disabled && "disabled",
            state.focused ? "focus" : ""
          )}
          {...props}
        >
          {slots.default?.({
            disabled,
            onFocus: () => (state.focused = true),
            onBlur: () => (state.focused = false),
          })}
        </Form.Item>
      );
    };
  },
});

const formItemStyles = css`
  transition: all 0.3s;
  align-items: center;
  &.border {
    border-bottom: 1px solid #efefef;
  }
  /* disabled */
  &.disabled {
    label {
      cursor: not-allowed;
      color: rgba(0, 0, 0, 0.25) !important;
    }
    .ant-select-disabled.ant-select:not(.ant-select-customize-input)
      .ant-select-selector,
    .ant-input-affix-wrapper-disabled {
      background-color: #fff !important;
    }
  }
  &:not(.disabled) {
    &:hover,
    &.focus {
      border-color: #5a7bef;
    }
    &.focus {
      box-shadow: 0px 1px 0px rgb(90 122 239 / 20%),
        0px 2px 0px rgb(90 122 239 / 10%) !important;
    }
  }

  /* error  */
  &.ant-form-item-has-error {
    border-color: #ff4d4f !important;
    &:hover,
    &.focus {
    }
    &.focus {
      box-shadow: 0px 1px 0px rgb(255 77 79 / 20%),
        0px 2px 0px rgb(255 77 79 / 10%) !important;
    }
  }

  &.ant-form-item-with-help {
    margin-bottom: 24px;
    .ant-form-item-explain {
      position: absolute;
      left: 0;
      bottom: -26px;
    }
  }

  .ant-form-item-label {
    width: 70px;
    label {
      color: #666;
    }
  }

  /* border style */
  .ant-select,
  .ant-input,
  .ant-select-selector,
  .ant-input-affix-wrapper {
    border: none !important;
    box-shadow: none !important;
  }
`;
